OpenELM API Reference
======================

Subpackages
-----------

.. toctree::
   :maxdepth: 1

   openelm.environments

Submodules
----------

ELM
-----------------------------------------

.. automodule:: openelm.elm
   :members:
   :undoc-members:
   :show-inheritance:
   :special-members: __init__

MAP-Elites
-----------------------------------------

.. automodule:: openelm.map_elites
   :members:
   :undoc-members:
   :show-inheritance:
   :special-members: __init__

Diff Models
-----------------------------------------

.. automodule:: openelm.diff_model
   :members:
   :undoc-members:
   :show-inheritance:
   :special-members: __init__
